pub struct FactSet {
pub nodes: Vec<Node>,
pub edges: Vec<Edge>,
}Expand description
The set of nodes and edges extracted from a single source blob (or otherwise
assembled together). Applying a fact set to a crate::Store is atomic.
Fields
nodes: Vec<Node>Nodes to upsert.
edges: Vec<Edge>Edges to insert (endpoints must resolve to nodes in this set or already present in the store).
Implementations