pub struct FindingsApplied {
pub layer: String,
pub findings: usize,
pub removed: usize,
pub replaced: bool,
}Expand description
A summary of replacing a findings layer (see
crate::Store::replace_findings_layer).
Fields
layer: StringThe layer key written.
findings: usizeFindings written by this ingest.
removed: usizeOwned finding rows deleted from the previous run of this layer. This is the number that proves obsolete records are removed rather than orphaned.
replaced: boolWhether a previous run of this layer existed and was replaced.