layer_key

Function layer_key 

pub fn layer_key(
    analyzer: &str,
    worktree: &WorktreeId,
) -> Result<String, FindingsError>
Render the layer key a findings layer is filed under: security:<analyzer>:<worktree-id>.

A successful re-ingest under the same key replaces the previous layer wholesale (see crate::Store::replace_findings_layer).

Errors

Returns FindingsError::InvalidAnalyzerId if analyzer is not 1..= MAX_ANALYZER_ID characters of lowercase [a-z0-9._-]; the error names which of those rules was broken.