Extractor

Trait Extractor 

pub trait Extractor {
    // Required method
    fn extract(&self, path: &str, blob_id: &str, bytes: &[u8]) -> FactSet;
}
Turns one source blob into the nodes and edges derived from it.

Required Methods

fn extract(&self, path: &str, blob_id: &str, bytes: &[u8]) -> FactSet

Extract a FactSet from a blob’s path, git blob_id, and bytes.

Implementations must be deterministic: identical inputs must always produce an identical fact set.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors